import {Component, OnInit, ViewChild} from '@angular/core';
import {opr_company_type, opr_team_type} from '../project.constants';
import {pageSize} from '../../app.constants';
import {WorkService} from '../../work/work.service';
import {NzMessageService} from 'ng-zorro-antd';
import {ProjectService} from '../project.service';
import {Router} from '@angular/router';
import {CommonService} from '../../shared/common/common.service';
import {DatePipe} from '@angular/common';
import {CreateTeamComponent} from '../modal/create-team/create-team.component';
import {TeamPeopleComponent} from '../modal/team-people/team-people.component';
import {TeamModalComponent} from '../modal/team-modal/team-modal.component';
import {LocalStorageService} from 'ngx-webstorage';

@Component({
    selector: 'app-opr-team',
    templateUrl: './opr-team.component.html',
    styleUrls: ['./opr-team.component.css']
})
export class OprTeamComponent implements OnInit {
    @ViewChild('smartCreateTeam') smartCreateTeam: CreateTeamComponent;
    @ViewChild('smartTeamModal') smartTeamModal: TeamModalComponent;
    teamType = [{label: '全部', value: null}, ...opr_team_type];

    page = {
        list: [],
        isLoading: false,
        pageCount: pageSize,
        pageNum: 1,
        totalNum: null
    };

    obj = {
        name: '',
        type: null
    };
    userId;

    constructor(private workSer: WorkService, private message: NzMessageService, private projectSer: ProjectService,
                private $localStorage:LocalStorageService,
                private router: Router, private commonSer: CommonService, private datePipe: DatePipe) {
    }

    ngOnInit() {
        this.userId = this.$localStorage.retrieve('userInfo').userId;
        this.getList();
    }

    //获取列表
    getList() {
        this.page.isLoading = true;
        const obj = {
            obj: this.obj,
            pageNum: this.page.pageNum,
            pageCount: this.page.pageCount
        };
        this.projectSer.selectMaintainTeam(obj).subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.page.list = res.data.data;
                    this.page.totalNum = res.data.totalNum;
                    this.page.isLoading = false;
                }
            }
        );
    }

    //翻页
    change(e) {
        if (e > 0) {
            this.page.pageNum = e;
            this.getList();
        }
    }

    //搜索
    search() {
        this.page.pageNum = 1;
        this.getList();
    }

    //新增运维团队
    handleAdd() {
        this.smartCreateTeam.showAddModal('新增运维团队');
    }

    //编辑团队
    handleEdit(item) {
        this.smartCreateTeam.showEditModal(item, '编辑运维团队');
    }

    //团队成员修改
    handleUpdateTeam(data) {
        this.smartTeamModal.showModal(data, `团队成员`);
    }

    //删除
    handleDelete(item){
        this.commonSer.confirmThing('删除',"确定删除该团队?",()=>{
            const data = {
                id:item.id
            };
            this.projectSer.deleteMaintainTeam(data).subscribe(
                (res)=>{
                    if(res.errCode == 10000){
                        this.message.success('删除成功!');
                        this.getList();
                    }
                }
            )
        })
    }
}
